EXPORTS
	?DiskSpaceBelowCriticalLevel_OldL@SysUtil@@CAHPAVRFs@@HH@Z @ 1 NONAME ; int SysUtil::DiskSpaceBelowCriticalLevel_OldL(class RFs *, int, int)
	?FFSSpaceBelowCriticalLevel_OldL@SysUtil@@CAHPAVRFs@@H@Z @ 2 NONAME ; int SysUtil::FFSSpaceBelowCriticalLevel_OldL(class RFs *, int)
	?Dummy1@Dummy@@SAHXZ @ 3 NONAME ; int Dummy::Dummy1(void)
	?GetLangSWVersion@SysUtil@@SAHAAVTDes16@@@Z @ 4 NONAME ; int SysUtil::GetLangSWVersion(class TDes16 &)
	?GetLangVersion@SysUtil@@SAHAAVTDes16@@@Z @ 5 NONAME ; int SysUtil::GetLangVersion(class TDes16 &)
	?GetSWVersion@SysUtil@@SAHAAVTDes16@@@Z @ 6 NONAME ; int SysUtil::GetSWVersion(class TDes16 &)
	?Dummy2@Dummy@@SAXXZ @ 7 NONAME ; void Dummy::Dummy2(void)
	?Dummy3@Dummy@@SAXXZ @ 8 NONAME ; void Dummy::Dummy3(void)
	?Dummy4@Dummy@@SAXXZ @ 9 NONAME ; void Dummy::Dummy4(void)
	?MMCSpaceBelowCriticalLevel_OldL@SysUtil@@CAHPAVRFs@@H@Z @ 10 NONAME ; int SysUtil::MMCSpaceBelowCriticalLevel_OldL(class RFs *, int)
	?Dummy5@Dummy@@SAXXZ @ 11 NONAME ; void Dummy::Dummy5(void)
	?Dummy6@Dummy@@SAXXZ @ 12 NONAME ; void Dummy::Dummy6(void)
	?Dummy7@Dummy@@SAXXZ @ 13 NONAME ; void Dummy::Dummy7(void)
	?Dummy8@Dummy@@SAXXZ @ 14 NONAME ; void Dummy::Dummy8(void)
	?Dummy9@Dummy@@SAXXZ @ 15 NONAME ; void Dummy::Dummy9(void)
	?Dummy10@Dummy@@SAXXZ @ 16 NONAME ; void Dummy::Dummy10(void)
	?Dummy11@Dummy@@SAXXZ @ 17 NONAME ; void Dummy::Dummy11(void)
	?Dummy12@Dummy@@SAXXZ @ 18 NONAME ; void Dummy::Dummy12(void)
	?Dummy13@Dummy@@SAXXZ @ 19 NONAME ; void Dummy::Dummy13(void)
	?Dummy14@Dummy@@SAXXZ @ 20 NONAME ; void Dummy::Dummy14(void)
	?KSysUtilOtherDiskCriticalThreshold@@3HB @ 21 NONAME ; int const KSysUtilOtherDiskCriticalThreshold
	?KSysUtilDefaultMMCDrive@@3HB @ 22 NONAME ; int const KSysUtilDefaultMMCDrive
	?KSysUtilRamDiskCriticalThreshold@@3HB @ 23 NONAME ; int const KSysUtilRamDiskCriticalThreshold
	?KSysUtilDefaultFFSDrive@@3HB @ 24 NONAME ; int const KSysUtilDefaultFFSDrive
	?Dummy15@Dummy@@SAXXZ @ 25 NONAME ; void Dummy::Dummy15(void)
	?Dummy16@Dummy@@SAXXZ @ 26 NONAME ; void Dummy::Dummy16(void)
	?Dummy17@Dummy@@SAXXZ @ 27 NONAME ; void Dummy::Dummy17(void)
	?Dummy18@Dummy@@SAXXZ @ 28 NONAME ; void Dummy::Dummy18(void)
	?Dummy19@Dummy@@SAXXZ @ 29 NONAME ; void Dummy::Dummy19(void)
	?Dummy20@Dummy@@SAXXZ @ 30 NONAME ; void Dummy::Dummy20(void)
	?Dummy21@Dummy@@SAXXZ @ 31 NONAME ; void Dummy::Dummy21(void)
	?Dummy22@Dummy@@SAXXZ @ 32 NONAME ; void Dummy::Dummy22(void)
	?Dummy23@Dummy@@SAXXZ @ 33 NONAME ; void Dummy::Dummy23(void)
	?Dummy24@Dummy@@SAXXZ @ 34 NONAME ; void Dummy::Dummy24(void)
	?Dummy25@Dummy@@SAXXZ @ 35 NONAME ; void Dummy::Dummy25(void)
	?Dummy26@Dummy@@SAXXZ @ 36 NONAME ; void Dummy::Dummy26(void)
	?Dummy27@Dummy@@SAXXZ @ 37 NONAME ; void Dummy::Dummy27(void)
	?Dummy28@Dummy@@SAXXZ @ 38 NONAME ; void Dummy::Dummy28(void)
	?Dummy29@Dummy@@SAXXZ @ 39 NONAME ; void Dummy::Dummy29(void)
	?Dummy30@Dummy@@SAXXZ @ 40 NONAME ; void Dummy::Dummy30(void)
	?GetFFSDriveLetter@SysUtil@@SAHAAVRFs@@@Z @ 41 NONAME ; int SysUtil::GetFFSDriveLetter(class RFs &)
	?GetMMCDriveLetter@SysUtil@@SAHAAVRFs@@@Z @ 42 NONAME ; int SysUtil::GetMMCDriveLetter(class RFs &)
	Reserved43 @ 43 NONAME ABSENT
	Reserved44 @ 44 NONAME ABSENT
	Reserved45 @ 45 NONAME ABSENT
	Reserved46 @ 46 NONAME ABSENT
	Reserved47 @ 47 NONAME ABSENT
	Reserved48 @ 48 NONAME ABSENT
	Reserved49 @ 49 NONAME ABSENT
	Reserved50 @ 50 NONAME ABSENT
	??1CDeviceTypeInformation@@UAE@XZ @ 51 NONAME ; CDeviceTypeInformation::~CDeviceTypeInformation(void)
	?GetDeviceTypeInfoL@SysUtil@@SAPAVCDeviceTypeInformation@@XZ @ 52 NONAME ; class CDeviceTypeInformation * SysUtil::GetDeviceTypeInfoL(void)
	?GetAttribute@CDeviceTypeInformation@@QBEHABVTUid@@AAVTPtrC16@@@Z @ 53 NONAME ; int CDeviceTypeInformation::GetAttribute(class TUid const &, class TPtrC16 &) const
	?KSysUtilDisableVersionSetupExe@@3HB @ 54 NONAME ; int const KSysUtilDisableVersionSetupExe
	?GetUIPlatformName@CDeviceTypeInformation@@QBEHAAVTPtrC16@@@Z @ 55 NONAME ; int CDeviceTypeInformation::GetUIPlatformName(class TPtrC16 &) const
	?KSysUtilDisableDeviceTypeInfoSetupExe@@3HB @ 56 NONAME ; int const KSysUtilDisableDeviceTypeInfoSetupExe
	?GetManufacturerName@CDeviceTypeInformation@@QBEHAAVTPtrC16@@@Z @ 57 NONAME ; int CDeviceTypeInformation::GetManufacturerName(class TPtrC16 &) const
	?GetOSVersion@CDeviceTypeInformation@@QBEHAAVTPtrC16@@@Z @ 58 NONAME ; int CDeviceTypeInformation::GetOSVersion(class TPtrC16 &) const
	?SetDeviceTypeInfoPropertyL@@YAXXZ @ 59 NONAME ; void SetDeviceTypeInfoPropertyL(void)
	?KSysUtilTestModeEnabled@@3HB @ 60 NONAME ; int const KSysUtilTestModeEnabled
	?GetRevisionID@CDeviceTypeInformation@@QBEHAAVTPtrC16@@@Z @ 61 NONAME ; int CDeviceTypeInformation::GetRevisionID(class TPtrC16 &) const
	?SetVersionPropertiesL@@YAXXZ @ 62 NONAME ; void SetVersionPropertiesL(void)
	?GetOSVersion@CDeviceTypeInformation@@QBEHAAG0@Z @ 63 NONAME ; int CDeviceTypeInformation::GetOSVersion(unsigned short &, unsigned short &) const
	?GetModelName@CDeviceTypeInformation@@QBEHAAVTPtrC16@@@Z @ 64 NONAME ; int CDeviceTypeInformation::GetModelName(class TPtrC16 &) const
	?GetUIPlatformVersion@CDeviceTypeInformation@@QBEHAAG0@Z @ 65 NONAME ; int CDeviceTypeInformation::GetUIPlatformVersion(unsigned short &, unsigned short &) const
	?GetDefaultDeviceName@CDeviceTypeInformation@@QBEHAAVTPtrC16@@@Z @ 66 NONAME ; int CDeviceTypeInformation::GetDefaultDeviceName(class TPtrC16 &) const
	?GetUIPlatformVersion@CDeviceTypeInformation@@QBEHAAVTPtrC16@@@Z @ 67 NONAME ; int CDeviceTypeInformation::GetUIPlatformVersion(class TPtrC16 &) const
	?DeletePSPropertiesL@@YAXXZ @ 68 NONAME ; void DeletePSPropertiesL(void)
	?GetModelCode@CDeviceTypeInformation@@QBEHAAVTPtrC16@@@Z @ 69 NONAME ; int CDeviceTypeInformation::GetModelCode(class TPtrC16 &) const
	?FFSSpaceBelowCriticalLevelL@SysUtil@@SAHPAVRFs@@_J@Z @ 70 NONAME ; int SysUtil::FFSSpaceBelowCriticalLevelL(class RFs *, long long)
	?MMCSpaceBelowCriticalLevelL@SysUtil@@SAHPAVRFs@@_J@Z @ 71 NONAME ; int SysUtil::MMCSpaceBelowCriticalLevelL(class RFs *, long long)
	?DiskSpaceBelowCriticalLevelL@SysUtil@@SAHPAVRFs@@_JH@Z @ 72 NONAME ; int SysUtil::DiskSpaceBelowCriticalLevelL(class RFs *, long long, int)
	?GetPRInformation@SysUtil@@SAHAAVTDes16@@@Z @ 73 NONAME ; int SysUtil::GetPRInformation(class TDes16 &)

